@@ -413,7 +413,7 @@ elseif (hasRequest('action') && getRequest('action') === 'triggerprototype.massu
 	}
 
 	if ($result) {
-		unset($_REQUEST['form'], $_REQUEST['g_triggerid']);
+		unset($_REQUEST['massupdate'], $_REQUEST['form'], $_REQUEST['g_triggerid']);
 		uncheckTableRows(getRequest('parent_discoveryid'));
 	}
 	show_messages($result, _('Trigger prototypes updated'), _('Cannot update trigger prototypes'));
@@ -470,7 +470,8 @@ $config = select_config();
 /*
  * Display
  */
-if (hasRequest('action') && getRequest('action') === 'triggerprototype.massupdateform' && hasRequest('g_triggerid')) {
+if ((getRequest('action') === 'triggerprototype.massupdateform' || hasRequest('massupdate'))
+		&& hasRequest('g_triggerid')) {
 	$data = getTriggerMassupdateFormData();
 	$data['action'] = 'triggerprototype.massupdate';
 	$data['hostid'] = $discoveryRule['hostid'];
@@ -503,7 +504,7 @@ elseif (isset($_REQUEST['form'])) {
 		'recovery_expression_constructor' => getRequest('recovery_expression_constructor', IM_ESTABLISHED),
 		'limited' => false,
 		'templates' => [],
-		'hostid' => getRequest('hostid', 0),
+		'hostid' => getRequest('hostid', $discoveryRule['hostid']),
 		'expression_action' => $expression_action,
 		'recovery_expression_action' => $recovery_expression_action,
 		'tags' => getRequest('tags', []),
@@ -512,8 +513,6 @@ elseif (isset($_REQUEST['form'])) {
 		'manual_close' => getRequest('manual_close', ZBX_TRIGGER_MANUAL_CLOSE_NOT_ALLOWED)
 	]);
 
-	$data['hostid'] = $discoveryRule['hostid'];
-
 	$triggersView = new CView('configuration.trigger.prototype.edit', $data);
 	$triggersView->render();
 	$triggersView->show();
